@@ -76,7 +76,12 @@ sub call {
 
   return $self->$mapper(sub{
     my ($key, $val) = @_;
-    Venus::Type->new($val)->deduce->$method(@args)
+
+    my $type = Venus::Type->new($val)->deduce;
+
+    local $_ = $type;
+
+    $type->$method(@args)
   });
 }
 
@@ -445,6 +450,22 @@ sub shift {
   return CORE::shift(@$data);
 }
 
+sub shuffle {
+  my ($self) = @_;
+
+  my $data = $self->get;
+  my $result = [@$data];
+
+  for my $index (0..$#$result) {
+    my $other = int(rand(@$result));
+    my $stash = $result->[$index];
+    $result->[$index] = $result->[$other];
+    $result->[$other] = $stash;
+  }
+
+  return $result;
+}
+
 sub slice {
   my ($self, @args) = @_;
 
@@ -3166,6 +3187,30 @@ I<Since C<0.01>>
 
 =cut
 
+=head2 shuffle
+
+  shuffle() (ArrayRef)
+
+The shuffle method returns an array with the items in a randomized order.
+
+I<Since C<1.40>>
+
+=over 4
+
+=item shuffle example 1
+
+  # given: synopsis
+
+  package main;
+
+  my $shuffle = $array->shuffle;
+
+  # [4, 5, 8, 7, 2, 9, 6, 3, 1]
+
+=back
+
+=cut
+
 =head2 slice
 
   slice(Str @keys) (ArrayRef)
