@@ -11,6 +11,16 @@ base 'Venus::Kind';
 
 with 'Venus::Role::Buildable';
 
+# BUILDERS
+
+sub build_arg {
+  my ($self, $data) = @_;
+
+  return {
+    value => $data,
+  };
+}
+
 1;
 
 
