@@ -55,6 +55,18 @@ sub build_proxy {
 
 # METHODS
 
+sub assertion {
+  my ($self) = @_;
+
+  my $assert = $self->SUPER::assertion;
+
+  $assert->constraints->clear;
+
+  $assert->constraint('array', true);
+
+  return $assert;
+}
+
 sub default {
   my ($self) = @_;
 
